//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Tatsu](../index.md)/[Companion](index.md)

# Companion

[common]\
object [Companion](index.md)

## Functions

| Name | Summary |
|---|---|
| [invoke](invoke.md) | [common]<br>operator fun [invoke](invoke.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Tatsu](../index.md)<br>operator fun [invoke](invoke.md)(first: [Tile](../../-tile/index.md), second: [Tile](../../-tile/index.md)): [Tatsu](../index.md) |
| [parse](parse.md) | [common]<br>fun [parse](parse.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Tatsu](../index.md)<br>根据给定牌的文本构造搭子<br>[common]<br>fun [parse](parse.md)(first: [Tile](../../-tile/index.md), second: [Tile](../../-tile/index.md)): [Tatsu](../index.md)<br>根据给定牌构造搭子 |
